using System;
using Cpp2IlInjected;
using UnityEngine;

// Token: 0x02000024 RID: 36
[Token(Token = "0x2000024")]
public class VoiceBoss03Big : MonoBehaviour
{
	// Token: 0x0600010F RID: 271 RVA: 0x000054C4 File Offset: 0x000036C4
	[Token(Token = "0x600010F")]
	[Address(RVA = "0x9394A0", Offset = "0x9382A0", VA = "0x1809394A0")]
	public void InitData(Transform Parent)
	{
		/*
An exception occurred when decompiling this method (0600010F)

ICSharpCode.Decompiler.DecompilerException: Error decompiling System.Void VoiceBoss03Big::InitData(UnityEngine.Transform)

 ---> System.Exception: Basic block has to end with unconditional control flow. 
{; 	Block_0:; 	stloc:SoundEffect(var_0_0C, call:SoundEffect(Common::GetSoundEffectOfPrefabs, ldfld:GameObject(VoiceBoss03Big::SE_Debut, ldloc:VoiceBoss03Big(this)), ldloc:Transform(Parent))); 	stfld:SoundEffect(VoiceBoss03Big::g_SEDebut, ldloc:VoiceBoss03Big(this), ldloc:SoundEffect(var_0_0C)); 	stloc:SoundEffect(var_1_20, call:SoundEffect(Common::GetSoundEffectOfPrefabs, ldfld:GameObject(VoiceBoss03Big::SE_Attack01, ldloc:VoiceBoss03Big(this)), ldloc:Transform(Parent))); 	stfld:SoundEffect(VoiceBoss03Big::g_SEAttack01, ldloc:VoiceBoss03Big(this), ldloc:SoundEffect(var_1_20)); 	stloc:SoundEffect(var_2_34, call:SoundEffect(Common::GetSoundEffectOfPrefabs, ldfld:GameObject(VoiceBoss03Big::SE_Attack02, ldloc:VoiceBoss03Big(this)), ldloc:Transform(Parent))); 	stfld:SoundEffect(VoiceBoss03Big::g_SEAttack02, ldloc:VoiceBoss03Big(this), ldloc:SoundEffect(var_2_34)); 	stloc:SoundEffect(var_3_48, call:SoundEffect(Common::GetSoundEffectOfPrefabs, ldfld:GameObject(VoiceBoss03Big::SE_Sweep, ldloc:VoiceBoss03Big(this)), ldloc:Transform(Parent))); 	stfld:SoundEffect(VoiceBoss03Big::g_SESweep, ldloc:VoiceBoss03Big(this), ldloc:SoundEffect(var_3_48)); 	stloc:SoundEffect(var_4_5C, call:SoundEffect(Common::GetSoundEffectOfPrefabs, ldfld:GameObject(VoiceBoss03Big::SE_SplashMagma, ldloc:VoiceBoss03Big(this)), ldloc:Transform(Parent))); 	stfld:SoundEffect(VoiceBoss03Big::g_SESplashMagma, ldloc:VoiceBoss03Big(this), ldloc:SoundEffect(var_4_5C)); 	stloc:SoundEffect(var_5_72, call:SoundEffect(Common::GetSoundEffectOfPrefabs, ldfld:GameObject(VoiceBoss03Big::SE_FireBall, ldloc:VoiceBoss03Big(this)), ldloc:Transform(Parent))); 	stfld:SoundEffect(VoiceBoss03Big::g_SEFireBall, ldloc:VoiceBoss03Big(this), ldloc:SoundEffect(var_5_72)); 	stloc:SoundEffect(var_6_88, call:SoundEffect(Common::GetSoundEffectOfPrefabs, ldfld:GameObject(VoiceBoss03Big::SE_Charge, ldloc:VoiceBoss03Big(this)), ldloc:Transform(Parent))); 	stfld:SoundEffect(VoiceBoss03Big::g_SECharge, ldloc:VoiceBoss03Big(this), ldloc:SoundEffect(var_6_88)); 	stloc:SoundEffect(var_7_9E, call:SoundEffect(Common::GetSoundEffectOfPrefabs, ldfld:GameObject(VoiceBoss03Big::SE_ChargeAttack, ldloc:VoiceBoss03Big(this)), ldloc:Transform(Parent))); 	stfld:SoundEffect(VoiceBoss03Big::g_SEChargeAttack, ldloc:VoiceBoss03Big(this), ldloc:SoundEffect(var_7_9E)); 	stloc:SoundEffect(var_8_B4, call:SoundEffect(Common::GetSoundEffectOfPrefabs, ldfld:GameObject(VoiceBoss03Big::SE_ChargeThrow, ldloc:VoiceBoss03Big(this)), ldloc:Transform(Parent))); 	stfld:SoundEffect(VoiceBoss03Big::g_SEChargeThrow, ldloc:VoiceBoss03Big(this), ldloc:SoundEffect(var_8_B4)); 	stloc:SoundEffect(var_9_CA, call:SoundEffect(Common::GetSoundEffectOfPrefabs, ldfld:GameObject(VoiceBoss03Big::SE_ChargeDamage, ldloc:VoiceBoss03Big(this)), ldloc:Transform(Parent))); 	stfld:SoundEffect(VoiceBoss03Big::g_SEChargeDamage, ldloc:VoiceBoss03Big(this), ldloc:SoundEffect(var_9_CA)); 	stloc:SoundEffect(var_10_E0, call:SoundEffect(Common::GetSoundEffectOfPrefabs, ldfld:GameObject(VoiceBoss03Big::SE_Death, ldloc:VoiceBoss03Big(this)), ldloc:Transform(Parent))); 	stfld:SoundEffect(VoiceBoss03Big::g_SEDeath, ldloc:VoiceBoss03Big(this), ldloc:SoundEffect(var_10_E0)); }; 
   at ICSharpCode.Decompiler.ILAst.ILAstOptimizer.FlattenBasicBlocks(ILNode node) in D:\a\dnSpy\dnSpy\Extensions\ILSpy.Decompiler\ICSharpCode.Decompiler\ICSharpCode.Decompiler\ILAst\ILAstOptimizer.cs:line 1810
   at ICSharpCode.Decompiler.ILAst.ILAstOptimizer.Optimize(DecompilerContext context, ILBlock method, AutoPropertyProvider autoPropertyProvider, StateMachineKind& stateMachineKind, MethodDef& inlinedMethod, AsyncMethodDebugInfo& asyncInfo, ILAstOptimizationStep abortBeforeStep) in D:\a\dnSpy\dnSpy\Extensions\ILSpy.Decompiler\ICSharpCode.Decompiler\ICSharpCode.Decompiler\ILAst\ILAstOptimizer.cs:line 344
   at ICSharpCode.Decompiler.Ast.AstMethodBodyBuilder.CreateMethodBody(IEnumerable`1 parameters, MethodDebugInfoBuilder& builder) in D:\a\dnSpy\dnSpy\Extensions\ILSpy.Decompiler\ICSharpCode.Decompiler\ICSharpCode.Decompiler\Ast\AstMethodBodyBuilder.cs:line 123
   at ICSharpCode.Decompiler.Ast.AstMethodBodyBuilder.CreateMethodBody(MethodDef methodDef, DecompilerContext context, AutoPropertyProvider autoPropertyProvider, IEnumerable`1 parameters, Boolean valueParameterIsKeyword, StringBuilder sb, MethodDebugInfoBuilder& stmtsBuilder) in D:\a\dnSpy\dnSpy\Extensions\ILSpy.Decompiler\ICSharpCode.Decompiler\ICSharpCode.Decompiler\Ast\AstMethodBodyBuilder.cs:line 88
   --- End of inner exception stack trace ---
   at ICSharpCode.Decompiler.Ast.AstMethodBodyBuilder.CreateMethodBody(MethodDef methodDef, DecompilerContext context, AutoPropertyProvider autoPropertyProvider, IEnumerable`1 parameters, Boolean valueParameterIsKeyword, StringBuilder sb, MethodDebugInfoBuilder& stmtsBuilder) in D:\a\dnSpy\dnSpy\Extensions\ILSpy.Decompiler\ICSharpCode.Decompiler\ICSharpCode.Decompiler\Ast\AstMethodBodyBuilder.cs:line 92
   at ICSharpCode.Decompiler.Ast.AstBuilder.AddMethodBody(EntityDeclaration methodNode, EntityDeclaration& updatedNode, MethodDef method, IEnumerable`1 parameters, Boolean valueParameterIsKeyword, MethodKind methodKind) in D:\a\dnSpy\dnSpy\Extensions\ILSpy.Decompiler\ICSharpCode.Decompiler\ICSharpCode.Decompiler\Ast\AstBuilder.cs:line 1618
*/;
	}

	// Token: 0x06000110 RID: 272 RVA: 0x000055BC File Offset: 0x000037BC
	[Token(Token = "0x6000110")]
	[Address(RVA = "0x939790", Offset = "0x938590", VA = "0x180939790")]
	private void Update()
	{
		do
		{
			float stageDeltaTime = Game.GetStageDeltaTime();
			if (0 < (int)stageDeltaTime)
			{
				goto Block_0;
			}
		}
		while (!this.g_SECharge.GetIsPlaying());
		while (this.g_bSECharge)
		{
		}
		this.g_SECharge.Pause();
		this.g_bSECharge = true;
		return;
		Block_0:
		if (this.g_bSECharge)
		{
			this.g_SECharge.Continue();
			this.g_bSECharge = false;
		}
	}

	// Token: 0x06000111 RID: 273 RVA: 0x00005620 File Offset: 0x00003820
	[Token(Token = "0x6000111")]
	[Address(RVA = "0x939470", Offset = "0x938270", VA = "0x180939470")]
	public void PlayVoiceDebut()
	{
		this.g_SEDebut.PlayRandom(1f, 1f);
	}

	// Token: 0x06000112 RID: 274 RVA: 0x00005648 File Offset: 0x00003848
	[Token(Token = "0x6000112")]
	[Address(RVA = "0x9392B0", Offset = "0x9380B0", VA = "0x1809392B0")]
	public void PlayVoiceAttack01()
	{
		this.g_SEAttack01.PlayRandom(1f, 1f);
	}

	// Token: 0x06000113 RID: 275 RVA: 0x00005670 File Offset: 0x00003870
	[Token(Token = "0x6000113")]
	[Address(RVA = "0x939620", Offset = "0x938420", VA = "0x180939620")]
	public void PlayVoiceAttack02()
	{
		this.g_SEAttack02.PlayRandom(1f, 1f);
	}

	// Token: 0x06000114 RID: 276 RVA: 0x00005698 File Offset: 0x00003898
	[Token(Token = "0x6000114")]
	[Address(RVA = "0x939730", Offset = "0x938530", VA = "0x180939730")]
	public void PlayVoiceSweep()
	{
		this.g_SESweep.PlayRandom(1f, 1f);
	}

	// Token: 0x06000115 RID: 277 RVA: 0x000056C0 File Offset: 0x000038C0
	[Token(Token = "0x6000115")]
	[Address(RVA = "0x9396F0", Offset = "0x9384F0", VA = "0x1809396F0")]
	public void PlayVoiceSplashMagma(int i)
	{
		this.g_SESplashMagma.Play(i, 1f, 1f);
	}

	// Token: 0x06000116 RID: 278 RVA: 0x000056EC File Offset: 0x000038EC
	[Token(Token = "0x6000116")]
	[Address(RVA = "0x9392E0", Offset = "0x9380E0", VA = "0x1809392E0")]
	public void PlayVoiceFireBall()
	{
		this.g_SEFireBall.PlayRandom(1f, 1f);
	}

	// Token: 0x06000117 RID: 279 RVA: 0x00005714 File Offset: 0x00003914
	[Token(Token = "0x6000117")]
	[Address(RVA = "0x938770", Offset = "0x937570", VA = "0x180938770")]
	public void PlayVoiceChargeAttack()
	{
		this.g_SEChargeAttack.PlayRandom(1f, 1f);
	}

	// Token: 0x06000118 RID: 280 RVA: 0x0000573C File Offset: 0x0000393C
	[Token(Token = "0x6000118")]
	[Address(RVA = "0x939680", Offset = "0x938480", VA = "0x180939680")]
	public void PlayVoiceChargeThrow()
	{
		this.g_SEChargeThrow.PlayRandom(1f, 1f);
	}

	// Token: 0x06000119 RID: 281 RVA: 0x00005764 File Offset: 0x00003964
	[Token(Token = "0x6000119")]
	[Address(RVA = "0x939650", Offset = "0x938450", VA = "0x180939650")]
	public void PlayVoiceChargeDamage()
	{
		this.g_SEChargeDamage.PlayRandom(1f, 1f);
	}

	// Token: 0x0600011A RID: 282 RVA: 0x0000578C File Offset: 0x0000398C
	[Token(Token = "0x600011A")]
	[Address(RVA = "0x9396B0", Offset = "0x9384B0", VA = "0x1809396B0")]
	public void PlayVoiceDeath(int i)
	{
		this.g_SEDeath.Play(i, 1f, 1f);
	}

	// Token: 0x0600011B RID: 283 RVA: 0x000057B8 File Offset: 0x000039B8
	[Token(Token = "0x600011B")]
	[Address(RVA = "0x939340", Offset = "0x938140", VA = "0x180939340")]
	public void PlayVoiceCharge(int i)
	{
		this.g_SECharge.Play(i, 1f, 1f);
	}

	// Token: 0x0600011C RID: 284 RVA: 0x000057E4 File Offset: 0x000039E4
	[Token(Token = "0x600011C")]
	[Address(RVA = "0x939760", Offset = "0x938560", VA = "0x180939760")]
	public void StopVoiceCharge()
	{
		this.g_SECharge.Stop();
	}

	// Token: 0x0600011D RID: 285 RVA: 0x00005804 File Offset: 0x00003A04
	[Token(Token = "0x600011D")]
	[Address(RVA = "0x3088F0", Offset = "0x3076F0", VA = "0x1803088F0")]
	public VoiceBoss03Big()
	{
	}

	// Token: 0x04000170 RID: 368
	[FieldOffset(Offset = "0x18")]
	[Token(Token = "0x4000170")]
	public GameObject SE_Debut;

	// Token: 0x04000171 RID: 369
	[FieldOffset(Offset = "0x20")]
	[Token(Token = "0x4000171")]
	public GameObject SE_Attack01;

	// Token: 0x04000172 RID: 370
	[FieldOffset(Offset = "0x28")]
	[Token(Token = "0x4000172")]
	public GameObject SE_Attack02;

	// Token: 0x04000173 RID: 371
	[FieldOffset(Offset = "0x30")]
	[Token(Token = "0x4000173")]
	public GameObject SE_Sweep;

	// Token: 0x04000174 RID: 372
	[FieldOffset(Offset = "0x38")]
	[Token(Token = "0x4000174")]
	public GameObject SE_SplashMagma;

	// Token: 0x04000175 RID: 373
	[FieldOffset(Offset = "0x40")]
	[Token(Token = "0x4000175")]
	public GameObject SE_FireBall;

	// Token: 0x04000176 RID: 374
	[FieldOffset(Offset = "0x48")]
	[Token(Token = "0x4000176")]
	public GameObject SE_Charge;

	// Token: 0x04000177 RID: 375
	[FieldOffset(Offset = "0x50")]
	[Token(Token = "0x4000177")]
	public GameObject SE_ChargeAttack;

	// Token: 0x04000178 RID: 376
	[FieldOffset(Offset = "0x58")]
	[Token(Token = "0x4000178")]
	public GameObject SE_ChargeThrow;

	// Token: 0x04000179 RID: 377
	[FieldOffset(Offset = "0x60")]
	[Token(Token = "0x4000179")]
	public GameObject SE_ChargeDamage;

	// Token: 0x0400017A RID: 378
	[FieldOffset(Offset = "0x68")]
	[Token(Token = "0x400017A")]
	public GameObject SE_Death;

	// Token: 0x0400017B RID: 379
	[FieldOffset(Offset = "0x70")]
	[Token(Token = "0x400017B")]
	private SoundEffect g_SEDebut;

	// Token: 0x0400017C RID: 380
	[FieldOffset(Offset = "0x78")]
	[Token(Token = "0x400017C")]
	private SoundEffect g_SEAttack01;

	// Token: 0x0400017D RID: 381
	[FieldOffset(Offset = "0x80")]
	[Token(Token = "0x400017D")]
	private SoundEffect g_SEAttack02;

	// Token: 0x0400017E RID: 382
	[FieldOffset(Offset = "0x88")]
	[Token(Token = "0x400017E")]
	private SoundEffect g_SESweep;

	// Token: 0x0400017F RID: 383
	[FieldOffset(Offset = "0x90")]
	[Token(Token = "0x400017F")]
	private SoundEffect g_SESplashMagma;

	// Token: 0x04000180 RID: 384
	[FieldOffset(Offset = "0x98")]
	[Token(Token = "0x4000180")]
	private SoundEffect g_SEFireBall;

	// Token: 0x04000181 RID: 385
	[FieldOffset(Offset = "0xA0")]
	[Token(Token = "0x4000181")]
	private SoundEffect g_SECharge;

	// Token: 0x04000182 RID: 386
	[FieldOffset(Offset = "0xA8")]
	[Token(Token = "0x4000182")]
	private SoundEffect g_SEChargeAttack;

	// Token: 0x04000183 RID: 387
	[FieldOffset(Offset = "0xB0")]
	[Token(Token = "0x4000183")]
	private SoundEffect g_SEChargeThrow;

	// Token: 0x04000184 RID: 388
	[FieldOffset(Offset = "0xB8")]
	[Token(Token = "0x4000184")]
	private SoundEffect g_SEChargeDamage;

	// Token: 0x04000185 RID: 389
	[FieldOffset(Offset = "0xC0")]
	[Token(Token = "0x4000185")]
	private SoundEffect g_SEDeath;

	// Token: 0x04000186 RID: 390
	[FieldOffset(Offset = "0xC8")]
	[Token(Token = "0x4000186")]
	private bool g_bSECharge;
}
